@@ -5,7 +5,7 @@
 ;; Author: Niklas Eklund <niklas.eklund@posteo.net>
 ;; Maintainer: detached.el Development <~niklaseklund/detached.el@lists.sr.ht>
 ;; URL: https://sr.ht/~niklaseklund/detached.el/
-;; Version: 0.8.0
+;; Version: 0.8.1
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: convenience processes
 
@@ -59,12 +59,12 @@
 
 ;;;;; Customizable
 
-(defcustom detached-session-directory (expand-file-name "detached" (temporary-file-directory))
+(defcustom detached-session-directory (expand-file-name "detached" user-emacs-directory)
   "The directory to store sessions."
   :type 'string
   :group 'detached)
 
-(defcustom detached-db-directory user-emacs-directory
+(defcustom detached-db-directory (expand-file-name "detached" user-emacs-directory)
   "The directory to store the `detached' database."
   :type 'string
   :group 'detached)
@@ -199,7 +199,7 @@ Valid values are: create, new and attach")
 (defvar detached-metadata-annotators-alist nil
   "An alist of annotators for metadata.")
 
-(defconst detached-session-version "0.8.0.0"
+(defconst detached-session-version "0.8.1.0"
   "The version of `detached-session'.
 This version is encoded as [package-version].[revision].")
 
@@ -283,6 +283,7 @@ This version is encoded as [package-version].[revision].")
   (command nil :read-only t)
   (origin nil :read-only t)
   (working-directory nil :read-only t)
+  (initial-mode nil)
   (directory nil :read-only t)
   (metadata nil :read-only t)
   (host nil :read-only t)
@@ -380,6 +381,7 @@ The session is compiled by opening its output and enabling
   (when (detached-valid-session session)
     (let* ((default-directory
              (detached--session-working-directory session))
+           (detached-session-mode (detached--session-initial-mode session))
            (detached-session-action (detached--session-action session))
            (command (detached--session-command session)))
       (if suppress-output
@@ -577,6 +579,7 @@ active session.  For sessions created with `detached-compile' or
                                     :action detached-session-action
                                     :working-directory (detached--get-working-directory)
                                     :degraded (detached-degraded-command-p command)
+                                    :initial-mode detached-session-mode
                                     :time `(:start ,(time-to-seconds (current-time)) :end 0.0 :duration 0.0 :offset 0.0)
                                     :status '(unknown . 0)
                                     :size 0
@@ -595,21 +598,24 @@ active session.  For sessions created with `detached-compile' or
 
 Optionally SUPPRESS-OUTPUT."
   (let ((inhibit-message t)
-        (detached-enabled t)
-        (detached--current-session
-         (or detached--current-session
-             (detached-create-session command))))
+        (detached-enabled t))
     (if-let ((run-in-background
               (or suppress-output
                   (eq detached-session-mode 'create)))
              (detached-session-mode 'create))
-        (progn (setq detached-enabled nil)
-               (if detached-local-session
-                   (apply #'start-process-shell-command
-                          `("detached" nil ,(detached--dtach-command detached--current-session t)))
-                 (apply #'start-file-process-shell-command
-                        `("detached" nil ,(detached--dtach-command detached--current-session t)))))
+        (let ((detached--current-session
+               (or detached--current-session
+                   (detached-create-session command))))
+          (setq detached-enabled nil)
+          (if detached-local-session
+              (apply #'start-process-shell-command
+                     `("detached" nil ,(detached--dtach-command detached--current-session t)))
+            (apply #'start-file-process-shell-command
+                   `("detached" nil ,(detached--dtach-command detached--current-session t)))))
       (cl-letf* ((detached-session-mode 'create-and-attach)
+                 (detached--current-session
+                  (or detached--current-session
+                      (detached-create-session command)))
                  ((symbol-function #'set-process-sentinel) #'ignore)
                  (buffer (get-buffer-create detached--shell-command-buffer))
                  (command (detached--shell-command detached--current-session t)))
@@ -667,7 +673,7 @@ Optionally SUPPRESS-OUTPUT."
     (unless (file-exists-p detached-db-directory)
       (make-directory detached-db-directory t))
     (detached--db-initialize)
-    (detached--register-detached-emacs )
+    (detached--register-detached-emacs)
     (setq detached--db-watch
           (file-notify-add-watch detached-db-directory
                                  '(change attribute-change)
@@ -1380,8 +1386,7 @@ If event is cased by an update to the `detached' database, re-initialize
 
 (defun detached--metadata-git-branch ()
   "Return current git branch."
-  (let ((args '("symbolic-ref" "HEAD" "--short"))
-        (process-file-return-signal-string t))
+  (let ((args '("symbolic-ref" "HEAD" "--short")))
     (with-temp-buffer
       (when (= 0 (apply #'process-file `("git" nil t nil ,@args)))
         (unless (bobp)
